@@ -31,6 +31,7 @@ signals:
 public slots:
     void setYouTubeDownloadQuality(const QString &quality);
     void setDownloadPath(const QString &path);
+    void setXTubeDownloadPath(const QString &path);
     void startDownload(const QVariantMap &video);
     void pauseDownload();
     void cancelDownload();
@@ -39,8 +40,10 @@ public slots:
 private slots:
     void parseYouTubeVideoPage(QNetworkReply *reply);
     void parseDailymotionVideoPage();
+    void parseYouPornVideoPage();
     void getYouTubeVideoUrl(const QString &videoId);
     void getDailymotionVideoUrl(const QString &videoId);
+    void getYouPornVideoUrl(const QString &url);
     void performDownload(const QUrl &videoUrl);
     void updateSize();
     void updateProgress(qint64 bytesReceived, qint64 bytesTotal);
@@ -61,6 +64,7 @@ private:
     QNetworkReply *downloadReply;
     QTime downloadTime;
     QString downloadPath;
+    QString xtubeDownloadPath;
     QVariantMap videoToDownload;
     QProcess *converter;
 
