@@ -10,6 +10,7 @@
 #include "settings.h"
 #include "folderlistmodel.h"
 #include "utils.h"
+#include "xtube.h"
 
 int main(int argc, char *argv[])
 {
@@ -18,6 +19,7 @@ int main(int argc, char *argv[])
 
     YouTube yt;
     Dailymotion daily;
+    XTube xt;
     Database db;
     DownloadManager dm;
     Settings settings;
@@ -26,6 +28,7 @@ int main(int argc, char *argv[])
     QNetworkAccessManager *manager = new QNetworkAccessManager();
     yt.setNetworkAccessManager(manager);
     daily.setNetworkAccessManager(manager);
+    xt.setNetworkAccessManager(manager);
     dm.setNetworkAccessManager(manager);
 
     QObject::connect(&app, SIGNAL(aboutToQuit()), &settings, SLOT(saveSettings()));
@@ -35,17 +38,21 @@ int main(int argc, char *argv[])
     QObject::connect(&settings, SIGNAL(dailymotionAccountChanged(QString,QString,QString,int)), &daily, SLOT(setAccount(QString,QString,QString,int)));
     QObject::connect(&settings, SIGNAL(youtubeDownloadQualityChanged(QString)), &dm, SLOT(setYouTubeDownloadQuality(QString)));
     QObject::connect(&settings, SIGNAL(downloadPathChanged(QString)), &dm, SLOT(setDownloadPath(QString)));
+    QObject::connect(&settings, SIGNAL(xtubeDownloadPathChanged(QString)), &dm, SLOT(setXTubeDownloadPath(QString)));
     QObject::connect(&settings, SIGNAL(mediaPlayerChanged(QString)), &ut, SLOT(setMediaPlayer(QString)));
     QObject::connect(&settings, SIGNAL(orientationChanged(QString)), &viewer, SLOT(setScreenOrientation(QString)));
+    QObject::connect(&yt, SIGNAL(signedOut()), &settings, SLOT(clearYouTubeAccount()));
     QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
     QObject::connect(&daily, SIGNAL(gotVideoUrl(QString)), &ut, SLOT(playVideo(QString)));
     QObject::connect(&daily, SIGNAL(signedIn(QString,QString,QString,int)), &settings, SLOT(setDailymotionAccount(QString,QString,QString,int)));
+    QObject::connect(&daily, SIGNAL(signedOut()), &settings, SLOT(clearDailymotionAccount()));
 
     qmlRegisterType<QDeclarativeFolderListModel>("Models",1,0,"FolderListModel");
 
     QDeclarativeContext *context = viewer.rootContext();
     context->setContextProperty("YouTube", &yt);
     context->setContextProperty("Dailymotion", &daily);
+    context->setContextProperty("XTube", &xt);
     context->setContextProperty("DownloadManager", &dm);
     context->setContextProperty("Database", &db);
     context->setContextProperty("Settings", &settings);
