@@ -1,10 +1,13 @@
 Qt.include("createobject.js");
 
-function getYouTubeSearch(query, order) {
+function getYouTubeSearch(query, order, durationFilter) {
     var encodedQuery = encodeURIComponent(query.replace(/\s.\s/gi, " "));
     var safe = Settings.safeSearch ? "strict" : "none";
     var videoFeed = "http://gdata.youtube.com/feeds/api/videos?v=2&max-results=30&safeSearch=" + safe + "&q=%22"
         + encodedQuery + "%22%7C" + encodedQuery.replace(/\s/g, "+") + "&orderby=" + order + "&alt=json";
+    if (durationFilter != "all") {
+        videoFeed += "&duration=" + durationFilter;
+    }
     return videoFeed;
 }
 
