@@ -4,9 +4,13 @@
 #include <QObject>
 #include <QProcess>
 #include <QVariantList>
+#include <QSystemInfo>
+#include <QSystemDeviceInfo>
 
 class QWidget;
 
+using namespace QtMobility;
+
 #include "qmlapplicationviewer.h"
 
 class Utils : public QObject {
@@ -15,12 +19,16 @@ class Utils : public QObject {
     Q_PROPERTY(QString currentTime
                READ getCurrentTime
                NOTIFY currentTimeChanged)
+    Q_PROPERTY(int batteryLevel
+               READ getBatteryLevel
+               NOTIFY batteryLevelChanged)
 
 public:
     explicit Utils(QObject *parent = 0);
 
     void setView(QmlApplicationViewer* view);
-    QString getCurrentTime() const { return currentTime; }
+    QString getCurrentTime() const;
+    int getBatteryLevel() const;
 
 public slots:
 
@@ -35,18 +43,18 @@ public slots:
     bool pathExists(const QString &path);
     void copyToClipboard(const QString &url);
     QString getDocsDirectory() const;
-
-private slots:
-    void updateCurrentTime();
+    QString getInstalledQtVersion() const;
 
 private:
     QmlApplicationViewer *viewer;
     QString mediaPlayer;
-    QString currentTime;
+    QSystemInfo *systemInfo;
+    QSystemDeviceInfo *deviceInfo;
 
 signals:
     void alert(const QString &message);
     void currentTimeChanged();
+    void batteryLevelChanged();
 };
 
 #endif // UTILS_H
