@@ -43,6 +43,32 @@ void YouTube::setAccessToken(const QString &token) {
     emit userSignedInChanged();
 }
 
+void YouTube::signOut() {
+    QUrl url(QString("https://www.google.com/accounts/AuthSubRevokeToken"));
+    QNetworkRequest request(url);
+    request.setRawHeader("Authorization", "AuthSub token=" + accessToken.toAscii());
+    QNetworkReply *reply = nam->get(request);
+    connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedOut()));
+}
+
+void YouTube::checkIfSignedOut() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    if (!reply) {
+        emit alert(tr("Unable to revoke access to your YouTube account"));
+        return;
+    }
+
+    int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    if (statusCode == 200) {
+        emit signedOut();
+        emit alert(tr("You have signed out of your YouTube account"));
+    }
+    else {
+        emit alert(tr("Unable to revoke access to your YouTube account"));
+    }
+    reply->deleteLater();
+}
+
 void YouTube::setMonitorClipboard(bool monitor) {
     if (monitor) {
         connect(clipboard, SIGNAL(dataChanged()), this, SLOT(getVideoLinks()));
