@@ -60,6 +60,7 @@ public slots:
     void uploadVideo(const QVariantMap &video);
     void abortVideoUpload();
     void setMonitorClipboard(bool monitor);
+    void signOut();
 
 private slots:
     void setUploadUrl();
@@ -75,6 +76,7 @@ private slots:
     void parseVideoPage(QNetworkReply *reply);
     void setIsUploading(const bool isUploading) { uploading = isUploading; emit uploadingChanged(); }
     void getVideoLinks();
+    void checkIfSignedOut();
 
 private:
     QNetworkAccessManager *nam;
@@ -123,6 +125,7 @@ signals:
     void userSignedInChanged();
     void uploadingChanged();
     void gotVideoIds(const QStringList &ids);
+    void signedOut();
 };
 
 #endif // YouTube_H
